@@ -78,7 +78,7 @@ pub fn derive_service_uri(input: proc_macro::TokenStream) -> proc_macro::TokenSt
 
   let expanded = quote! {
     impl env_url::ServiceURL for #ident {
-      fn service_url() -> Result<env_url::url::Url, env_url::url::ParseError> {
+      fn service_url(&self) -> Result<env_url::url::Url, env_url::url::ParseError> {
         let service_url_env = std::env::var(#prefixed_url_env_key).unwrap_or_else(|_| String::from(#prefixed_url_key));
 
         let service_url = std::env::var(service_url_env).unwrap_or_else(|_| {
